@@ -31,12 +31,23 @@ impl Parser {
         }
     }
     // todo: docs
+    // returns double empty Result for
     ///
-    pub fn lex(&mut self) {
-        self.lexer.lex();
+    pub fn lex(&mut self) -> Result<(),()> {
+        let lex_result = self.lexer.lex();
+        if let Ok(_) = lex_result {
+            println!("{:?}", self.lexer.tokens);
+            return Ok(());
+        } else if let Err(mut e) = lex_result {
+            e.module_name = self.module.id.id.clone();
+            print!("{}", e);
+            return Err(());
+        } else {Err(())}
     }
 }
 
+// todo: Docs
+// todo: Might change this entirely
 pub enum ParserError {
     UnexpectedToken(String, u64, u64, u64),
     MissingExpectedToken(String, u64, u64, u64),
