@@ -5,7 +5,7 @@ use wright::run;
 
 fn main() {
     if let Some(i) = argparser::argparse(env::args()) {
-        process::exit(run::interpret(i));
+        process::exit(run::interpret_file(i));
     } else {
         process::exit(0);
     }
